@@ -28,6 +28,7 @@
 #' \item{scale}{Estimated standard deviation of the Box-Cox transformed data.}
 #' \item{shape}{Estimated transformation parameter \eqn{\lambda}.}
 #' \item{bc.norm.rvs}{The random variables generated by the Box-Cox (or, equivalently, power-normal) distribution during the Monte Carlo simulation. If Monte Carlo simulation is not used, a value of \code{NA} is given.}
+#' \item{...}{Some additional elements.}
 #'
 #' The results are printed with the \code{\link{print.bc.mean.sd}} function.
 #'
@@ -53,13 +54,11 @@
 bc.mean.sd <- function(min.val, q1.val, med.val, q3.val, max.val, n,
                        preserve.tail = FALSE, avoid.mc = FALSE) {
 
+  args <- as.list(environment())
+
   scenario <- get.scenario(min.val, q1.val, med.val, q3.val, max.val)
-  if (missing(n)) {
-    stop("Need to specify n")
-  }
-  if (is.na(n) | n < 3 | n > 1e6){
-    stop("Value of n must be between 3 and 1,000,000")
-  }
+  check_errors(min.val = min.val, q1.val = q1.val, med.val = med.val,
+               q3.val = q3.val, max.val = max.val, n = n, scenario = scenario)
 
   location.scale.shape <- get.location.scale.shape(min.val, q1.val, med.val,
                                                    q3.val, max.val, n, scenario)
@@ -111,10 +110,12 @@ bc.mean.sd <- function(min.val, q1.val, med.val, q3.val, max.val, n,
     } else {
       bc.norm.rvs <- inv.smooth.bc.transform(trans.norm.rvs, shape)
     }
+
     output <- list(est.mean = as.numeric(mean(bc.norm.rvs)),
                    est.sd = as.numeric(stats::sd(bc.norm.rvs)),
                    location = as.numeric(location), scale = as.numeric(scale),
-                   shape = as.numeric(shape), bc.norm.rvs = bc.norm.rvs)
+                   shape = as.numeric(shape), bc.norm.rvs = bc.norm.rvs,
+                   args = args, scenario = scenario)
   }
   class(output) <- "bc.mean.sd"
   return(output)
